program RunJava;

{ Run a Java program with a custom JVM executable and CLASSPATH
  environment variable. This information is stored in the registry,
  under HKEY_CURRENT_USER\Software\Tempest Software\RunJava\
  with a subkey of the Java class name. The string variable JVM
  holds the path to the executable (default is java.exe). The
  string variable CLASSPATH holds the value for the CLASSPATH
  variable. The default is to inherit CLASSPATH from the
  global environment.

  This main purpose of this program is to demonstrate the Environ
  unit in Delphi, not to be a practical Java utility.
}

uses
  SysUtils,
  Registry,
  Environ,
  Launch in 'LAUNCH.PAS';

var
  JavaClass: string;        { name of the Java class }
  Dir: string;              { directory for the Java class }
  JvmPath: string;          { complete path to the Java executable }
  ClassPath: string;        { CLASSPATH environment variable }
  EnvBlock: TEnvBlock;      { new environment block }
  Reg: TRegIniFile;
begin
  if ParamCount <> 1 then
    raise Exception.CreateFmt('Usage: %s class-filename', [ParamStr(0)]);

  { Get the JVM and CLASSPATH info from the registry. }
  JavaClass := ChangeFileExt(ExtractFileName(ParamStr(1)), '');
  Dir := ExtractFilePath(ExpandFileName(ParamStr(1)));
  Reg := TRegIniFile.Create('\Software\Tempest Software\RunJava');
  try
    JvmPath := Reg.ReadString(JavaClass, 'JVM', 'java.exe');
    ClassPath := Reg.ReadString(JavaClass, 'ClassPath', '');
  finally
    Reg.Free;
  end;

  { Empty string means don't change the CLASSPATH. }
  if ClassPath <> '' then
    Env['CLASSPATH'] := ClassPath;

  { Use the modified environment to launch Java. }
  EnvBlock := GetEnvBlock;
  try
    LaunchApp(JvmPath, JavaClass, Dir, EnvBlock);
  finally
    FreeEnvBlock(EnvBlock);
  end;
end.
